from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RtypeCls:
	"""Rtype commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rtype", core, parent)

	def set(self, cell_name: str, type_py: enums.ReportType) -> None:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:CQIReporting:RTYPe \n
		Snippet: driver.configure.signaling.lte.cell.cqiReporting.rtype.set(cell_name = '1', type_py = enums.ReportType.APERiodic) \n
		Selects the CQI reporting type. \n
			:param cell_name: No help available
			:param type_py: OFF: no reporting PERiodic: periodic CQI reporting APERiodic: aperiodic CQI reporting
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('type_py', type_py, DataType.Enum, enums.ReportType))
		self._core.io.write(f'CONFigure:SIGNaling:LTE:CELL:CQIReporting:RTYPe {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self, cell_name: str) -> enums.ReportType:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:CQIReporting:RTYPe \n
		Snippet: value: enums.ReportType = driver.configure.signaling.lte.cell.cqiReporting.rtype.get(cell_name = '1') \n
		Selects the CQI reporting type. \n
			:param cell_name: No help available
			:return: type_py: OFF: no reporting PERiodic: periodic CQI reporting APERiodic: aperiodic CQI reporting"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:LTE:CELL:CQIReporting:RTYPe? {param}')
		return Conversions.str_to_scalar_enum(response, enums.ReportType)
