from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Types import DataType
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HbWidthCls:
	"""HbWidth commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hbWidth", core, parent)

	def set(self, cell_name: str, bandwidth: enums.BandwidthHoping) -> None:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:SRS:DEDicated:HBWidth \n
		Snippet: driver.configure.signaling.lte.cell.srs.dedicated.hbWidth.set(cell_name = '1', bandwidth = enums.BandwidthHoping.HBW0) \n
		Configures the parameter 'srs-HoppingBandwidth'. Only configurable for the mode UDEFined. \n
			:param cell_name: No help available
			:param bandwidth: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('bandwidth', bandwidth, DataType.Enum, enums.BandwidthHoping))
		self._core.io.write(f'CONFigure:SIGNaling:LTE:CELL:SRS:DEDicated:HBWidth {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self, cell_name: str) -> enums.BandwidthHoping:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:SRS:DEDicated:HBWidth \n
		Snippet: value: enums.BandwidthHoping = driver.configure.signaling.lte.cell.srs.dedicated.hbWidth.get(cell_name = '1') \n
		Configures the parameter 'srs-HoppingBandwidth'. Only configurable for the mode UDEFined. \n
			:param cell_name: No help available
			:return: bandwidth: No help available"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:LTE:CELL:SRS:DEDicated:HBWidth? {param}')
		return Conversions.str_to_scalar_enum(response, enums.BandwidthHoping)
