from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FollowingCls:
	"""Following commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("following", core, parent)

	@property
	def ibChange(self):
		"""ibChange commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ibChange'):
			from .IbChange import IbChangeCls
			self._ibChange = IbChangeCls(self._core, self._cmd_group)
		return self._ibChange

	@property
	def fmode(self):
		"""fmode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fmode'):
			from .Fmode import FmodeCls
			self._fmode = FmodeCls(self._core, self._cmd_group)
		return self._fmode

	@property
	def block(self):
		"""block commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_block'):
			from .Block import BlockCls
			self._block = BlockCls(self._core, self._cmd_group)
		return self._block

	def clone(self) -> 'FollowingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FollowingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
