from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Types import DataType
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CmodeCls:
	"""Cmode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cmode", core, parent)

	def set(self, cell_name: str, mode: enums.ModeC) -> None:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:HARQ:UL:CMODe \n
		Snippet: driver.configure.signaling.nradio.cell.harq.uplink.cmode.set(cell_name = '1', mode = enums.ModeC.AUTO) \n
		Selects a mode for UL HARQ configuration. \n
			:param cell_name: No help available
			:param mode: NOTC: no UL HARQ AUTO: automatic configuration of the UL HARQ settings USER: user-defined configuration of the UL HARQ settings
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('mode', mode, DataType.Enum, enums.ModeC))
		self._core.io.write(f'CONFigure:SIGNaling:NRADio:CELL:HARQ:UL:CMODe {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self, cell_name: str) -> enums.ModeC:
		"""SCPI: [CONFigure]:SIGNaling:NRADio:CELL:HARQ:UL:CMODe \n
		Snippet: value: enums.ModeC = driver.configure.signaling.nradio.cell.harq.uplink.cmode.get(cell_name = '1') \n
		Selects a mode for UL HARQ configuration. \n
			:param cell_name: No help available
			:return: mode: NOTC: no UL HARQ AUTO: automatic configuration of the UL HARQ settings USER: user-defined configuration of the UL HARQ settings"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:NRADio:CELL:HARQ:UL:CMODe? {param}')
		return Conversions.str_to_scalar_enum(response, enums.ModeC)
